/*
 * Copyright (c) 2013 Meltytech, LLC
 * Author: Brian Matherly <pez4brian@yahoo.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.1
import QtQuick.Dialogs 1.1
import QtQuick.Controls 1.0
import QtQuick.Layouts 1.0
import Shotcut.Controls 1.0

Rectangle {
    width: 400
    height: 200
    color: 'transparent'
    
    function setStatus( inProgress ) {
        if (inProgress) {
            status.text = qsTr('Analyzing...')
        }
        else if (filter.get("results").length > 0 ) {
            status.text = qsTr('Analysis complete.')
        }
        else
        {
            status.text = qsTr('Click "Analyze" to use this filter.')
        }
    }

    Connections {
        target: filter
        onAnalyzeFinished: {
            setStatus(false)
            button.enabled = true
        }
    }

    ColumnLayout {
        anchors.fill: parent
        anchors.margins: 8

        RowLayout {
            spacing: 8
            Button {
                id: button
                text: qsTr('Analyze')
                onClicked: {
                    button.enabled = false
                    filter.analyze();
                }
            }
            Label {
                id: status
                Component.onCompleted: {
                    setStatus(false)
                }
            }
        }

        RowLayout {
            spacing: 8
            Label { text: qsTr('Target Loudness') }
            Slider {
                id: programSlider
                Layout.fillWidth: true
                Layout.minimumWidth: 100
                value: filter.get('program') * 1
                minimumValue: -50.0
                maximumValue: -10.0
                property bool isReady: false
                Component.onCompleted: isReady = true
                onValueChanged: {
                    if (isReady) {
                        programSpinner.value = value
                        filter.set('program', value)
                    }
                }
            }
            SpinBox {
                id: programSpinner
                Layout.minimumWidth: 100
                value: filter.get('program') * 1
                minimumValue: -50.0
                maximumValue: -10.0
                decimals: 1
                suffix: ' LUFS'
                onValueChanged: programSlider.value = value
            }
            UndoButton {
                onClicked: programSlider.value = -23.0
            }
        }

        Item {
            Layout.fillHeight: true;
        }
    }
}
